#
# spec file for package html-xml-utils
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           html-xml-utils
Version:        8.6
Release:        1.7
Summary:        A number of utilities for manipulating HTML and XML files
License:        W3C
Group:          Development/Languages/Other
URL:            https://www.w3.org/Tools/HTML-XML-utils/
Source:         https://www.w3.org/Tools/HTML-XML-utils/html-xml-utils-%{version}.tar.gz
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  libcurl-devel
BuildRequires:  libidn2-devel

%description
HTML-XML-utils provides a number of utilities for manipulating and
converting HTML and XML files in various ways.

%prep
%setup -q
chmod -x ChangeLog README

%build
%configure
make %{?_smp_mflags}

%install
%make_install
rm %{buildroot}%{_datadir}/doc/%{name}/COPYING

%files
%doc ChangeLog README
%license COPYING
%{_bindir}/*
%{_mandir}/man1/*.1*

%changelog
* Thu May  4 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 8.6:
  * tests/select34.sh: Use "tr" instead of "xarg" to replace \0 by
  \n. (The xargs command on BSD ignores empty input lines, the GNU
  version does not.) Also use "printf" instead of "echo" to write to
  the log file, because it seems to be more consistent between
  different shells.
  * hxselect.c: Fixed a bug in parsing octal escapes in the
  separator string (option -s). Patch provided by Jorrit Fahlke.
  * errexit.c: Removed. Consistently use err() and errx()
  everywhere.
  * hxwls.c, printlinks.c, hxcopy.c: Allow white space before and
  after URLs in attributes. (Allowed by HTML5.)
* Fri Apr  1 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 8.4:
  * hxselect.c: The :attr() pseudo-element was only matched if it
  was on the first selector, not if it was on a subsequent selector
  in a comma-separated list of selectors. (Found and fixed by Bas
  Ploeger.)
  * tests/select33.sh: Added test for multiple :attr()
  selectors. (Contributed by Bas Ploeger.)
* Fri Feb 11 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 8.3:
  * dtd.hash: Make <head> rather than <body> the preferred parent
  for <script>. Allow text in the <body> element, without requiring a
  <p> or other element around it.
  * tests/pipe5.sh, tests/pipe6.sh, tests/pipe7.sh: Added tests for
  the -H option of hxpipe.
  * hxpipe.c: Add option -H, which assumes the input is HTML and adds
  implied tags and parses script and style elements as literal text.
  hxpipe now outputs attributes in a normalized order
  (alphabetical). Remove a redundant "if".
* Tue Dec 21 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 8.1:
  * tests/select11.sh, tests/select12.sh, tests/select13.sh,
  tests/select19.sh, tests/select21.sh: Added some text and
  comments, to test that they are correctly skipped.
  * tests/select31.sh, tests/select32.sh, Makefile.am: Added two
  tests for the sibling selector (~).
  * selmatch.c: Sibling selector failed to skip non-element nodes.
  * dict.c: Deleting an entry with dict_destroy() made entries with
  the same hash value that were stored in subsequent slots
  inaccessible. The dict_destroy() function isn't used in any of the
  HTML-XML-utils, but other programs may borrow this module.
* Tue Nov  2 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 8.0:
  * selector.c, selmatch.c: Also parse and process the experimental
  ":is()" and ":where()" pseudo-classes. Correct a bug in parsing
  comma-separated selectors. Correct a bug in esc() that caused an
  empty string to fail (e.g., in [alt=""]. (The function esc() is not
  used, but could be used when debugging.)
  * tests/select14.sh: Test ":empty" in combination with another
  pseudo-class.
  * Makefile.am: Added tests select26.sh, select27.sh, select28.sh,
  select29.sh and select30.sh
  * configure.ac: Added AC_SYS_LARGEFILE to enable seek() to seek
  large files and the off_t type to be 64 bits on older, 32-bit
  systems. Also check for limits.h.
  * hxselect.1: Noted the known bug that case-insensitive selectors
  (option -i) only work with ASCII characters.
* Mon Jan 11 2021 Wang Jun <jgwang@suse.com>
- Update to version 7.9
  * unent.hash: gperf 3.1 generates size_t instead of unsigned int.
  * Makefile.am: Call gperf on unent.hash with "-k 1-6" instead of
    "-k 1,2,$ -D". Added test select25.sh.
  * select25.sh: Test added. (Contributed by Hugo Peixoto.)
  * selector.c: An attribute selector with an empty string such as
    [foo=''], resulted in a NULL value instead of an empty string,
    which led to a crash. (Found and fixed by Hugo Peixoto.)
* Thu Oct 24 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 7.8:
  * textwrap.c, langinfo.c, hxnormalize.c: Added knowledge about
  languages that do not use spaces between words. In such languages,
  a newline should not be converted to a space in outc() in
  textwrap.c, but only to a break opportunity.
  * hxtoc.c: The element to group headings in HTML5 is called
  HGROUP, not HEADER. The heading of a section (SECTION, ARTICLE,
  etc.) need not be the first element, there may be non-header
  elements before it.
  * hxwls.c: Print "longdesc", "classid" or "codebase" in the second
  column for the corresponding attribute. Also recognize srcset
  (somewhat).
  * hxnormalize.c: Added option -X to indicate the input is XML
  instead of HTML. Handle conversion of CDATA elements to XML by
  escaping < and & instead of adding <![CDATA[. Added corresponding
  test normalize13.sh.
* Sat Jul 14 2018 jengelh@inai.de
- Cut overly long description and trim bias.
* Sun May 27 2018 sebix+novell.com@sebix.at
- update to version 7.7:
  * dtd.hash: Don't include the arguments in the forward declaration
  of lookup_element(), because those arguments differ slightly
  depending on which version of gperf is used to generate dtd.c:
  "unsigned int" in gperf 3.0 vs "size_t" in gperf 3.1.
  * conficgure.ac: Check for libiconv with the AM_ICONV macro (from
  gettext) instead of AC_SEARCH_LIBS. (Advice from Christian
  Weisgerber, received via Anthony Bentley). That in turn requires
  adding config.rpath to the EXTRA_DIST in Makefile.am.
  * hxindex.c: Replaced fgets() by getline(), to allow lines of
  arbitrary length in the term database.
* Sun Feb 18 2018 sebix+novell.com@sebix.at
- update to version 7.6:
  * fix read uninitialized memory bug
- update to version 7.5:
  * bugfixes
  * Added support for HTML5 elements (source, audio, video)
* Sat Dec 30 2017 sebix+novell.com@sebix.at
- initial package for version 7.4
